@@ -73,18 +73,18 @@ class CrudRepository(ABC, Generic[T, ID]):
         raise NotImplementedError()
 
     @abstractmethod
-    def exists_by_id(self, id: ID) -> bool:
+    def exists_by_id(self, id_: ID) -> bool:
         """
         Returns whether an entity with the given id exists.
 
-        :param id: must not be None.
+        :param id_: must not be None.
         :return: true if an entity with the given id exists, false otherwise.
         :raises ValueError: if id is None.
         """
         raise NotImplementedError()
 
     @abstractmethod
-    def find_all(self, sort: Sort = None) -> List[T]:
+    def find_all(self, sort: Optional[Sort] = None) -> List[T]:
         """
         Returns all entities.
 
@@ -94,7 +94,7 @@ class CrudRepository(ABC, Generic[T, ID]):
         raise NotImplementedError()
 
     @abstractmethod
-    def find_all_by_id(self, ids: List[ID], sort: Sort = None) -> List[T]:
+    def find_all_by_id(self, ids: List[ID], sort: Optional[Sort] = None) -> List[T]:
         """
         Returns all entities with the given IDs.
 
@@ -108,11 +108,11 @@ class CrudRepository(ABC, Generic[T, ID]):
         raise NotImplementedError()
 
     @abstractmethod
-    def find_by_id(self, id: ID) -> Optional[T]:
+    def find_by_id(self, id_: ID) -> Optional[T]:
         """
         Retrieves an entity by its id.
 
-        :param id: must not be None.
+        :param id_: must not be None.
         :return: the entity with the given id or None if none found.
         :raises ValueError: if id is None.
         """
@@ -151,7 +151,7 @@ class PagingRepository(ABC, Generic[T, ID], CrudRepository[T, ID]):
     """
 
     @abstractmethod
-    def find_page(self, pageable: Pageable, sort: Sort = None) -> Page[T]:
+    def find_page(self, pageable: Pageable, sort: Optional[Sort] = None) -> Page[T]:
         """
         Returns a :class:`Page` of entities meeting the paging restriction provided in the :class:`Pageable` object.
 
